@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.2.1';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.3.0';
 #pod =encoding UTF-8
 #pod
 #pod =head1 SYNOPSIS
@@ -25,7 +25,6 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.2.1';
 #pod   See L<Pod::Elemental::PerlMunger>.
 #pod   Currently possible values: "replace_with_nothing",
 #pod   "replace_with_comment" (default), "replace_with_blank"
-#pod * C<nodoc> - Set this to 1 to prevent the generation of HTML documents under doc/
 #pod
 #pod =head1 OVERVIEW
 #pod
@@ -170,6 +169,15 @@ with 'Dist::Zilla::Role::PluginBundle::Easy';
 #
 sub mvp_multivalue_args { return qw(GatherDir.exclude_match) }
 
+#pod =for Pod::Coverage _warn
+#pod
+#pod =cut
+sub _warn {
+    my $name = __PACKAGE__;
+    $name =~ s/^Dist::Zilla::PluginBundle:://;
+    warn sprintf("[%s] %s\n", $name, join("", @_));
+}
+
 #pod =method add_plugins_if_wanted
 #pod
 #pod Adds the given plugins unless there is a configuration option given to the
@@ -188,7 +196,10 @@ sub add_plugins_if_wanted {
     foreach my $this_spec (@plugin_specs) {
         my $moniker = ref $this_spec ? $this_spec->[0] : $this_spec;
          # skip plugin if told by user
-        next if grep { $moniker =~ /^\Q$_\E$/ && $self->payload->{$_} =~ /^no$/i } keys %{$self->payload};
+        if (grep { $moniker =~ /^\Q$_\E$/ && $self->payload->{$_} =~ /^no$/i } keys %{$self->payload}) {
+            _warn("Skipping plugin $moniker");
+            next;
+        }
         # otherwise add to list
         push @plugin_specs_filtered, $this_spec;
     }
@@ -226,6 +237,8 @@ sub configure {
         )
     );
 
+    my $build_myself = $self->payload->{build_myself};
+
     $self->add_plugins_if_wanted(
         #
         # Files included
@@ -277,10 +290,10 @@ sub configure {
         #
         # Prerequisites
         #
-        'Prereqs::FromCPANfile',          # use prereqs from "cpanfile"
-        'Prereqs::AuthorDeps',            # "adds Dist::Zilla and the result of "dzil
-                                          # authordeps" to the 'develop' phase prerequisite list"
-        'AutoPrereqs',                    # extract prereqs from your modules
+        !$build_myself
+            ? 'Prereqs::FromCPANfile'     # use prereqs from "cpanfile"
+            : ['Prereqs' => { 'Dist::Zilla::Plugin::Prereqs::FromCPANfile' => 0 }], # add manually because [MAXHQ::BundleDepsDeep] wont see it
+        'AutoPrereqs',                    # collect prereqs from modules
         ['RemovePrereqs' => {
             'remove' => [ qw( strict ) ],
         }],
@@ -342,6 +355,12 @@ sub configure {
         'Git::Push',
 
         'ConfirmRelease',                 # ask for confirmation before releasing
+
+        # almost at the end to capture all other plugins
+        $build_myself ? 'MAXHQ::BundleDepsDeep' : (),
+        # after [MAXHQ::BundleDepsDeep] so that dependencies are not copied to phase "runtime"
+        'Prereqs::AuthorDeps',            # "adds Dist::Zilla and the result of "dzil
+                                          # authordeps" to the 'develop' phase prerequisite list"
     );
 }
 
@@ -351,7 +370,7 @@ __PACKAGE__->meta->make_immutable;
 {
     package Dist::Zilla::Plugin::ShareDir::ProjectDistDir;
     # ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.2.1';
+$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.3.0';
 use Moose;
     use namespace::autoclean;
 
@@ -389,6 +408,97 @@ use Moose;
     __PACKAGE__->meta->make_immutable;
 }
 
+{
+    package Dist::Zilla::Plugin::MAXHQ::BundleDepsDeep;
+    # ABSTRACT: register all needed plugins in a bundle as runtime requirements
+$Dist::Zilla::Plugin::MAXHQ::BundleDepsDeep::VERSION = '3.3.0';
+use Moose;
+    use namespace::autoclean;
+
+    with 'Dist::Zilla::Role::PrereqSource';
+
+    use Module::Metadata;
+    use Distribution::Metadata;
+
+    sub _warn {
+        my $name = __PACKAGE__;
+        $name =~ s/^Dist::Zilla::Plugin:://;
+        warn sprintf("[%s] %s\n", $name, join("", @_));
+    }
+
+    sub register_prereqs {
+        my ($self) = @_;
+
+        my $req = $self->zilla->prereqs; # class Dist::Zilla::Prereqs
+        my $cpan_req = $req->cpan_meta_prereqs; # class CPAN::Meta::Prereqs
+
+        #
+        # Add all "develop" phase prerequisites as "runtime" prerequisites
+        # because they might have been injected by plugins (and we assume all
+        # plugins of the pluginbundle will be used later, so the prerequisites
+        # are needed.
+        #
+        _warn("Copying plugins from phase 'develop' to 'runtime'");
+        my $devreq = $cpan_req->requirements_for('develop', 'requires'); # class CPAN::Meta::Requirements
+        my $devreq_str = $devreq->as_string_hash;
+        $self->zilla->register_prereqs(
+            {
+                phase => 'runtime',
+                type  => 'requires',
+            },
+            %$devreq_str,
+        );
+
+        #
+        # Add all active plugins as runtime requirements
+        # (if not already there with a version number)
+        #
+        _warn("Registering currently used plugins as 'runtime' requirements");
+
+        # Try to find list of Dist::Zilla's own packages
+        my $dzil_meta = Distribution::Metadata->new_from_module("Dist::Zilla");
+        my $dzil_pkg = {};
+        if ($dzil_meta->install_json) {
+            _warn "Excluding packages of Dist::Zilla distribution";
+            $dzil_pkg = $dzil_meta->install_json_hash->{provides};
+        }
+
+        # list of active plugins with currently installed versions
+        my $plugins = {
+            map {
+                my $mod = $_;
+                $mod = "Dist::Zilla" if $dzil_pkg->{$mod};
+                my $meta = Module::Metadata->new_from_module($mod);
+                $mod => $meta ? $meta->version->stringify : 0
+            }
+            map { ref } # get class name
+            @{$self->zilla->plugins} # RJBS mentions that this attribute might go away!
+        };
+
+        my $runreq = $cpan_req->requirements_for('runtime', 'requires'); # class CPAN::Meta::Requirements
+        my $runreq_str = $runreq->as_string_hash;
+
+        # add plugins as runtime requirements unless they're already defined
+        my $plugin_prereqs = {};
+        for my $module (sort keys %$plugins) {
+            my $ver = $runreq_str->{$module};
+            next if $ver;  # don't overwrite specs coming from elsewhere
+            $plugin_prereqs->{$module} = $plugins->{$module};
+        }
+        $self->zilla->register_prereqs(
+            {
+                phase => 'runtime',
+                type  => 'requires',
+            },
+            %$plugin_prereqs,
+        );
+    }
+
+    __PACKAGE__->meta->make_immutable;
+}
+
+1;
+
 __END__
 
 =pod
@@ -399,7 +509,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 3.2.1
+version 3.3.0
 
 =head1 SYNOPSIS
 
@@ -424,10 +534,6 @@ C<GatherDir.exclude_match> - a regex specifying which files or directories to ig
 
 C<PodWeaver.replacer> - Which replacer to use for POD sections. See L<Pod::Elemental::PerlMunger>. Currently possible values: "replace_with_nothing", "replace_with_comment" (default), "replace_with_blank"
 
-=item *
-
-C<nodoc> - Set this to 1 to prevent the generation of HTML documents under doc/
-
 =back
 
 =head1 OVERVIEW
@@ -568,6 +674,8 @@ E.g. plugin 'PruneCruft' is used unless the following is given:
 
 =for Pod::Coverage mvp_multivalue_args
 
+=for Pod::Coverage _warn
+
 =for Pod::Coverage configure
 
 =head1 AUTHOR
